﻿using System;
using NUnit.Framework;
using System.IO;
using iTextSharp.text.pdf;
using PDFCreator.TestUtilities;
using pdfforge.PDFCreator.Core.Settings.Enums;

namespace PDFCreator.Core.Test
{
    [TestFixture]
    [Category("LongRunning")]
    class PdfTest
    {
        private TestHelper _th;

        [SetUp]
        public void SetUp()
        {
            _th = new TestHelper("PDFTest");
        }

        [TearDown]
        public void CleanUp()
        {
            _th.CleanUp();
        }

        public void MakePdfTest()
        {
            Assert.AreEqual(1, _th.Job.OutputFiles.Count, "Job created more than one pdf file");
            Assert.IsTrue(File.Exists(_th.Job.OutputFiles[0]), "Outputfile does not exist");
            string content = File.ReadAllText(_th.Job.OutputFiles[0], System.Text.Encoding.Default);
           
            Assert.AreEqual('%', content[0]);
            Assert.AreEqual('P', content[1]);
            Assert.AreEqual('D', content[2]);
            Assert.AreEqual('F', content[3]);
            Assert.AreEqual('-', content[4]);

            Assert.AreEqual('F', content[content.Length - 2]);
            Assert.AreEqual('O', content[content.Length - 3]);
            Assert.AreEqual('E', content[content.Length - 4]);
            Assert.AreEqual('%', content[content.Length - 5]);
            Assert.AreEqual('%', content[content.Length - 6]);

            try
            {
                var doc = new PdfFileAnalyzer.PdfDocument();
                Assert.IsTrue(doc.ValidatePdfFile(_th.Job.OutputFiles[0]), "Invalid PdfFile");
            }
            catch (Exception ex)
            {
                Assert.Fail("Invalid PdfFile:" + ex.Message);
            }
        }

        [Test]
        public void PdfRegularTest()
        {
            _th.GenerateGsJob(PSfiles.ThreePDFCreatorTestpages, OutputFormat.Pdf);
            _th.RunGsJob();

            MakePdfTest();

            var reader = new PdfReader(_th.Job.OutputFiles[0]);
            PdfDictionary dict = reader.GetPageN(1);
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFX));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFA1));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFXVERSION));
        }

        [Test]
        public void PdfATest()
        {
            _th.GenerateGsJob(PSfiles.ThreePDFCreatorTestpages, OutputFormat.PdfA);
            _th.RunGsJob();

            MakePdfTest();

            var reader = new PdfReader(_th.Job.OutputFiles[0]);
            PdfDictionary dict = reader.GetPageN(1);
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFX));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFA1));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFXVERSION));
        }

        [Test]
        public void PdfXTest()
        {
            _th.GenerateGsJob(PSfiles.ThreePDFCreatorTestpages, OutputFormat.PdfX);
            _th.RunGsJob();

            MakePdfTest();

            var reader = new PdfReader(_th.Job.OutputFiles[0]);
            PdfDictionary dict = reader.GetPageN(1); 

            Assert.AreEqual(null, dict.GetAsString(PdfName.VERSION));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFX));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFA1));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFXVERSION));

            dict = reader.GetPageN(2);
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFX));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFA1));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFXVERSION));

            dict = reader.GetPageN(3);
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFX));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFA1));
            Assert.AreEqual(null, dict.Get(PdfName.GTS_PDFXVERSION));
        }
    }
}