﻿using System.IO;
using NUnit.Framework;
using PDFCreator.TestUtilities;
using pdfforge.PDFCreator.Core.Settings.Enums;

namespace PDFCreator.Core.Test
{
    [TestFixture]
    public class UniqueFilenameTest
    {
        private TestHelper _th;

        [SetUp]
        public void SetUp()
        {
            _th = new TestHelper("UniqueFilenameTest");
        }

        [TearDown]
        public void CleanUp()
        {
            if (_th != null)
                _th.CleanUp();

            TempFileHelper.CleanUp();
        }

        [Test]
        public void TestEnsureUniqueFilename()
        {
            string tempFolder = TempFileHelper.CreateTempFolder("TestEnsureUniqueFilename");

            _th.Profile.AutoSave.Enabled = true;
            _th.Profile.AutoSave.EnsureUniqueFilenames = true;

            _th.GenerateGsJob(PSfiles.PDFCreatorTestpage, OutputFormat.Pdf);

            _th.Job.AutoCleanUp = false;

            string outputFile = Path.Combine(tempFolder, "doc.pdf");
            _th.Job.OutputFilenameTemplate = outputFile;
            _th.RunGsJob();

            _th.GenerateGsJob(PSfiles.PDFCreatorTestpage, OutputFormat.Pdf);

            _th.Job.AutoCleanUp = false;

            _th.Job.OutputFilenameTemplate = outputFile;
            _th.RunGsJob();
            
            Assert.IsTrue(File.Exists(outputFile), "Outputfile does not exist!");
            Assert.IsTrue(File.Exists(Path.Combine(tempFolder, "doc_2.pdf")), "File generated by EnsureUniqueFilename does not exist!");
        }
    }
}
