﻿using NUnit.Framework;
using iTextSharp.text.pdf;
using PDFCreator.TestUtilities;
using pdfforge.PDFCreator.Core.Settings.Enums;

namespace PDFCreator.Core.Test
{
    [TestFixture]
    [Category("LongRunning")]
    class ViewerSettingsTest
    {
        private TestHelper _th;

        [SetUp]
        public void SetUp()
        {
            _th = new TestHelper("ViewerSettingsTest");

            /*
            Console.WriteLine(PdfWriter.PageModeFullScreen); //512
            Console.WriteLine(PdfWriter.PageModeUseAttachments); //2048
            Console.WriteLine(PdfWriter.PageModeUseNone); //64
            Console.WriteLine(PdfWriter.PageModeUseOC); //1024
            Console.WriteLine(PdfWriter.PageModeUseOutlines); //128
            Console.WriteLine(PdfWriter.PageModeUseThumbs); //256
            Console.WriteLine(PdfWriter.PageLayoutOneColumn); //2
            Console.WriteLine(PdfWriter.PageLayoutSinglePage); //1
            Console.WriteLine(PdfWriter.PageLayoutTwoColumnLeft); //4
            Console.WriteLine(PdfWriter.PageLayoutTwoColumnRight); //8
            Console.WriteLine(PdfWriter.PageLayoutTwoPageLeft); //16
            Console.WriteLine(PdfWriter.PageLayoutTwoPageRight); //32
            */
        }

        [TearDown]
        public void CleanUp()
        {
            _th.CleanUp();
        }

        [Test]
        public void TestDocViewAttachmentsPanelPageViewOneColumnStart1()
        {
            _th.Profile.PdfSettings.DocumentView = DocumentView.AttachmentsPanel;
            _th.Profile.PdfSettings.PageView = PageView.OneColumn;
            _th.Profile.PdfSettings.ViewerStartsOnPage = 1;
            TestViewerSettings();
        }
        
        [Test]
        public void TestDocViewContentGroupPanelPageViewOnePageStart2()
        {
            _th.Profile.PdfSettings.DocumentView = DocumentView.ContentGroupPanel;
            _th.Profile.PdfSettings.PageView = PageView.OnePage;
            _th.Profile.PdfSettings.ViewerStartsOnPage = 2;
            TestViewerSettings();
        }

        [Test]
        public void TestDocViewFullscreenPageViewTwoColumnsOddLeftStart3()
        {
            _th.Profile.PdfSettings.DocumentView = DocumentView.FullScreen;
            _th.Profile.PdfSettings.PageView = PageView.TwoColumnsOddLeft;
            _th.Profile.PdfSettings.ViewerStartsOnPage = 3;
            TestViewerSettings();
        }

        [Test]
        public void TestDocViewNoOutLineNoThumbnailImagesPageViewTwoColumnsOddRightStart4()
        {
            _th.Profile.PdfSettings.DocumentView = DocumentView.NoOutLineNoThumbnailImages;
            _th.Profile.PdfSettings.PageView = PageView.TwoColumnsOddRight;
            _th.Profile.PdfSettings.ViewerStartsOnPage = 4;
            TestViewerSettings();
        }

        [Test]
        public void TestDocViewOutlinePageViewTwoPagesOddLeftStart5()
        {
            _th.Profile.PdfSettings.DocumentView = DocumentView.Outline;
            _th.Profile.PdfSettings.PageView = PageView.TwoPagesOddLeft;
            _th.Profile.PdfSettings.ViewerStartsOnPage = 5;
            TestViewerSettings();
        }

        [Test]
        public void TestDocThumbnailImagesPanelPageViewTwoPagesOddRightStart6Forcedto5()
        {
            _th.Profile.PdfSettings.DocumentView = DocumentView.ThumbnailImages;
            _th.Profile.PdfSettings.PageView = PageView.TwoPagesOddRight;
            _th.Profile.PdfSettings.ViewerStartsOnPage = 6; 
            TestViewerSettings();
        }


        public void TestViewerSettings()
        {
            //_th.Profile.OpenViewer = true;
            _th.GenerateGsJob(PSfiles.PortraitLandscapeLandscapeLandscapePortrait, OutputFormat.Pdf);
            _th.RunGsJob();
            var pdfreader = new PdfReader(_th.Job.OutputFiles[0]);

            ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////DocView

            if (_th.Profile.PdfSettings.DocumentView == DocumentView.AttachmentsPanel)
                Assert.AreEqual(PdfWriter.PageModeUseAttachments,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseAttachments,
                    "DocView: Required AttachmentsPanel not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseAttachments,
                    "DocView: Unrequired AttachmentsPanel set");

            if (_th.Profile.PdfSettings.DocumentView == DocumentView.ContentGroupPanel)
                Assert.AreEqual(PdfWriter.PageModeUseOC, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseOC,
                    "DocView: Required ContentGroupPanel not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseOC,
                    "DocView: Unrequired ContentGroupPanel set");

            if (_th.Profile.PdfSettings.DocumentView == DocumentView.FullScreen)
                Assert.AreEqual(PdfWriter.PageModeFullScreen,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageModeFullScreen,
                    "DocView: Required FullScreen Mode not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeFullScreen,
                    "DocView: Unrequired FullScreen Mode set");

            if (_th.Profile.PdfSettings.DocumentView == DocumentView.NoOutLineNoThumbnailImages)
                Assert.AreEqual(PdfWriter.PageModeUseNone, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseNone,
                    "DocView: Required NoOutLineNoThumbnailImages not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseNone,
                    "DocView: Unrequired NoOutLineNoThumbnailImages set");

            if (_th.Profile.PdfSettings.DocumentView == DocumentView.Outline)
                Assert.AreEqual(PdfWriter.PageModeUseOutlines,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseOutlines,
                    "DocView: Required Outline Mode not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseOutlines,
                    "DocView: Unrequired Outline Mode set");

            if (_th.Profile.PdfSettings.DocumentView == DocumentView.ThumbnailImages)
                Assert.AreEqual(PdfWriter.PageModeUseThumbs,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseThumbs,
                    "DocView: Required ThumbnailImagese not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageModeUseThumbs,
                    "DocView: Unrequired ThumbnailImagese set");

            ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////PageView

            if (_th.Profile.PdfSettings.PageView == PageView.OneColumn)
                Assert.AreEqual(PdfWriter.PageLayoutOneColumn,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutOneColumn,
                    "PageView: Required OneColumn not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutOneColumn,
                    "PageView: Unrequired OneColumn set");

            if (_th.Profile.PdfSettings.PageView == PageView.OnePage)
                Assert.AreEqual(PdfWriter.PageLayoutSinglePage,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutSinglePage,
                    "PageView: Required OnePage not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutSinglePage,
                    "PageView: Unrequired OnePage set");

            if (_th.Profile.PdfSettings.PageView == PageView.TwoColumnsOddLeft)
                Assert.AreEqual(PdfWriter.PageLayoutTwoColumnLeft,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoColumnLeft,
                    "PageView: Required TwoPagesOddLeft not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoColumnLeft,
                    "PageView: Unrequired TwoPagesOddLeft set");

            if (_th.Profile.PdfSettings.PageView == PageView.TwoColumnsOddRight)
                Assert.AreEqual(PdfWriter.PageLayoutTwoColumnRight,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoColumnRight,
                    "PageView: Required TwoColumnsOddRight not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoColumnRight,
                    "PageView: Unrequired TwoColumnsOddRight set");

            if (_th.Profile.PdfSettings.PageView == PageView.TwoPagesOddLeft)
                Assert.AreEqual(PdfWriter.PageLayoutTwoPageLeft,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoPageLeft,
                    "PageView: Required TwoPagesOddLeft not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoPageLeft,
                    "PageView: Unrequired TwoPagesOddLeft set");

            if (_th.Profile.PdfSettings.PageView == PageView.TwoPagesOddRight)
                Assert.AreEqual(PdfWriter.PageLayoutTwoPageRight,
                    pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoPageRight,
                    "PageView: Required TwoPagesOddRight not set");
            else
                Assert.AreEqual(0, pdfreader.SimpleViewerPreferences & PdfWriter.PageLayoutTwoPageRight,
                    "PageView: Unrequired TwoPagesOddRight set");

            ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////StartPage
            bool pageViewSet = false;

            int startPage = _th.Profile.PdfSettings.ViewerStartsOnPage;
            if (startPage < 1)
                startPage = 1;
            if (startPage > pdfreader.NumberOfPages)
                startPage = pdfreader.NumberOfPages;

            PdfObject pdfo = pdfreader.Catalog.Get(PdfName.OPENACTION);
            if (pdfo != null)
            {
                var pdfa = (PdfArray) pdfo;

                // Get the page reference of the intended page
                PdfIndirectReference pageref = pdfreader.GetPageOrigRef(startPage);

                // The first element of the OpenAction contains the page ref
                PdfObject actionRef = pdfa[0];

                Assert.AreEqual(pageref.ToString(), actionRef.ToString(), "The page references do not match");
                pageViewSet = true;
            }

            pdfo = pdfreader.Catalog.Get(PdfName.PAGE);

            if (!pageViewSet && pdfo != null)
            {
                int page = int.Parse(pdfo.ToString());
                Assert.AreEqual(startPage, page, "Initial page is not set correctly");
                pageViewSet = true;
            }

            Assert.IsTrue(pageViewSet, "Initial page was not set");
        }
    }
}
