﻿using Microsoft.Win32;

namespace pdfforge.PDFCreator.Mail
{
    public class EmailClientFactory : IEmailClientFactory
    {
        public IEmailClient CreateEmailClient()
        {
            string defaultMailClient = FindDefaultMailClient();

            if (defaultMailClient != null)
            {
                if (defaultMailClient.Contains("Outlook") && OutlookClient.IsOutlookInstalled)
                    return new OutlookClient();
            }

            if (MapiClient.IsMapiClientInstalled)
            {
                var mapiClient = new MapiClient();
                mapiClient.StartInOwnThread = true;

                return mapiClient;
            }

            return null;
        }

        private static string FindDefaultMailClient()
        {
            object mailClient = Registry.GetValue(@"HKEY_LOCAL_MACHINE\SOFTWARE\Clients\Mail", "", "none");
            if (mailClient == null)
                return null;

            return mailClient.ToString();
        }
    }
}
