﻿using System;
using System.Linq;
using NLog;

namespace pdfforge.PDFCreator.Mail
{
    public class OutlookClient : IEmailClient
    {
        private readonly Logger _logger = LogManager.GetCurrentClassLogger();
        
        private static Type _outlookType;
        private static Type OutlookType
        {
            get
            {
                if (_outlookType == null)
                    _outlookType = Type.GetTypeFromProgID("Outlook.Application");

                return _outlookType;
            }
        }

        public static bool IsOutlookInstalled
        {
            get { return OutlookType != null; }
        }

        public bool IsClientInstalled
        {
            get { return IsOutlookInstalled; }
        }

        public bool ShowEmailClient(Email email)
        {
            _logger.Info("Starting Outlook");
            _logger.Info("Starting Outlook");
            if (!IsClientInstalled)
            {
                _logger.Error("Outlook is not installed!");
                return false;
            }

            try
            {
                dynamic outlook = Activator.CreateInstance(OutlookType);

                if (outlook == null)
                    return false;

                dynamic mail = outlook.CreateItem(0);

                mail.To = string.Join(";", email.To);
                //mail.CC = "";
                //mail.BCC = "";
                mail.Subject = email.Subject;
                mail.BodyFormat = 1;
                mail.Display();

                // We need to set the body after the mail is displayed to not overwrite the signature
                mail.Body = email.Body + mail.Body;

                foreach (var attachment in email.Attachments)
                {
                    mail.Attachments.Add(attachment.Filename);
                }

                _logger.Info("Done starting Outlook");

                return true;
            }
            catch (Exception ex)
            {
                _logger.ErrorException("Error while starting Outlook", ex);
                return false;
            }
        }
    }
}
