﻿using System;
using System.IO;
using Microsoft.Win32;

namespace pdfforge.PDFCreator.Core.Settings
{
    public static class PdfArchitectCheck
    {
        /// <summary>
        /// Check if Registry contains a programm with DisplayName "PDF Architect" and Publisher "pdfforge"  
        /// </summary>
        /// <returns>Returns installation path if Architect is installed, else null</returns>
        public static string InstallationPath()
        {
            string[] softwareKeys =
            {
                @"SOFTWARE\Wow6432Node\Microsoft\Windows\CurrentVersion\Uninstall"
                , @"SOFTWARE\Microsoft\Windows\CurrentVersion\Uninstall"
            };
            foreach (string key in softwareKeys)
            {
                using (RegistryKey rk = Registry.LocalMachine.OpenSubKey(key))
                {
                    if (rk == null)
                        continue;

                    //Let's go through the registry keys and get the info we need:
                    foreach (string skName in rk.GetSubKeyNames())
                    {
                        using (RegistryKey sk = rk.OpenSubKey(skName))
                        {
                            try
                            {
                                //first look for PDF Architect 2
                                //If the key has value, continue, if not, skip it:
                                if (sk.GetValue("DisplayName").ToString().StartsWith("PDF Architect 2"))
                                    if (sk.GetValue("Publisher").ToString().Contains("pdfforge"))
                                        if (sk.GetValue("InstallLocation") != null)
                                        {
                                            var installLocation = sk.GetValue("InstallLocation").ToString();
                                            return Path.Combine(installLocation, "PDF Architect 2.exe");
                                        }

                                //first look for PDF Architect 
                                //If the key has value, continue, if not, skip it:
                                if (sk.GetValue("DisplayName").ToString().StartsWith("PDF Architect"))
                                    if (sk.GetValue("Publisher").ToString().Contains("pdfforge"))
                                        if (sk.GetValue("InstallLocation") != null)
                                        {
                                            var installLocation = sk.GetValue("InstallLocation").ToString();
                                            return Path.Combine(installLocation, "PDF Architect.exe");
                                        }
                            }
                            catch (Exception)
                            {
                            }
                        }
                    }
                }
            }
            return null;
        }

        /// <summary>
        /// Check if Registry contains a Programm with DisplayName "PDF Architect" and Publisher "pdfforge"  
        /// </summary>
        /// <returns>Returns true, if PDF Architect is installed</returns>
        public static bool Installed()
        {
            return InstallationPath() != null;
        }
    }
}