﻿using System;
using System.Windows.Forms;
using NLog;
using NLog.Config;
using NLog.Targets;
using System.Threading;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.Threading;

namespace pdfforge.PDFCreator.Forms
{
    public partial class TestForm : Form
    {
        private static TextBox _logTextBox;

        public TestForm()
        {
            InitializeComponent();

            InitLogging();
        }

        /// <summary>
        /// Initialize Logging, Targets and Rules
        /// </summary>
        private void InitLogging()
        {
            LoggingConfiguration config = LogManager.Configuration;
            if (config == null)
                config = new LoggingConfiguration();

            var methodCallTarget = new MethodCallTarget();
            methodCallTarget.ClassName = GetType().AssemblyQualifiedName;
            methodCallTarget.MethodName = "LogMessage";
            methodCallTarget.Parameters.Add(new MethodCallParameter("${level}"));
            methodCallTarget.Parameters.Add(new MethodCallParameter("${message}"));

            config.AddTarget("method", methodCallTarget);
            config.LoggingRules.Add(new LoggingRule("*", LogLevel.Trace, methodCallTarget));
            LogManager.Configuration = config;
        }

        private void btnCreateJob_Click(object sender, EventArgs e)
        {
            JobInfoQueue.Instance.AddTestPage();
        }

        private void TestForm_FormClosing(object sender, FormClosingEventArgs e)
        {
            SettingsHelper.SaveSettings();
        }

        private void TestForm_Load(object sender, EventArgs e)
        {
            _logTextBox = txtLog;
        }

        delegate void LogMessageDelegate(string level, string message);
        public static void LogMessage(string level, string message)
        {
            if (_logTextBox == null)
                return; 
            
            // if coming from a different thread, use invoke
            if (_logTextBox.InvokeRequired)
            {
                _logTextBox.Invoke(new LogMessageDelegate(LogMessage), new object[] { level, message });
                return;
            }

            _logTextBox.Text += message + Environment.NewLine;
        }

        private void btnMainForm_Click(object sender, EventArgs e)
        {
            ThreadManager.Instance.StartMainWindowThread();
        }

        public static void ShowTestForm()
        {
            var t = new Thread(StartTestFormThread);
            t.Start();
        }

        private static void StartTestFormThread()
        {
            var f = new TestForm();
            f.ShowDialog();
        }

    }
}
