﻿using System;
using System.ComponentModel;
using System.Diagnostics;
using pdfforge.PDFCreator.Views;

namespace pdfforge.PDFCreator.Helper
{
    internal enum ShellExecuteResult
    {
        Success,
        Failed,
        RunAsWasDenied
    }

    internal static class ShellExecuteHelper
    {
        public static ShellExecuteResult RunAsAdmin(string path, string arguments)
        {
            var psi = new ProcessStartInfo();

            psi.FileName = path;
            psi.Arguments = arguments;
            psi.CreateNoWindow = true;
            psi.WindowStyle = ProcessWindowStyle.Hidden;

            // Use ShellExecute and RunAs starting with Windows Vista
            if (Environment.OSVersion.Version.Major >= 6)
            {
                psi.UseShellExecute = true;
                psi.Verb = "runas";
            }

            try
            {
                Process p = Process.Start(psi);
                p.WaitForExit(10000);

                if (p.ExitCode == 0)
                {
                    return ShellExecuteResult.Success;
                }

                return ShellExecuteResult.Failed;
            }
            catch (Win32Exception)
            {
                var message = TranslationUtil.GetTranslation("ApplicationSettingsWindow", "SufficientPermissions",
                    "Operation failed. Probably You do not have sufficient permissions.");
                var caption = TranslationUtil.GetTranslation("ApplicationSettingsWindow", "Error", "Error");

                MessageWindow.ShowTopMost(message, caption, MessageWindowButtons.OK, MessageWindowIcon.Error);

                return ShellExecuteResult.RunAsWasDenied;
            }
            catch (SystemException)
            {
                return ShellExecuteResult.Failed;
            }

        }
    }
}
