﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Win32;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class AttachmentActionControl : UserControl, IActionControl
    {
        public string DisplayName { get; private set; }
        public string Description { get; private set; }
        public UserControl UserControl { get { return this; } }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ViewModel.CurrentProfile.AttachmentPage.Enabled;
            }
            set
            {
                ViewModel.CurrentProfile.AttachmentPage.Enabled = value;
            }
        }

        public AttachmentActionControl()
        {
            InitializeComponent();

            DisplayName = TranslationUtil.GetTranslation("AttachmentSettings", "DisplayName", "Add attachment");
            Description = TranslationUtil.GetTranslation("AttachmentSettings", "Description", "Add an attachment to your documents.\r\nThe attachment file must be a PDF file and may contain multiple pages.");

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        private void SelectAttachmentFileButton_OnClick(object sender, RoutedEventArgs e)
        {
            var title = TranslationUtil.GetTranslation("AttachmentSettings", "SelectAttachmentFile", "Select attachment file");
            var filter = TranslationUtil.GetTranslation("AttachmentSettings", "PDFFiles", "PDF files")
                                    + @" (*.pdf)|*.pdf|"
                                    + TranslationUtil.GetTranslation("AttachmentSettings", "AllFiles", "All files")
                                    + @" (*.*)|*.*";
            
            FileDialogHelper.ShowSelectFileDialog(AttachmentFileTextBox, title, filter);
        }
    }
}