﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Win32;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    /// <summary>
    /// Interaktionslogik für BackgroundActionControl.xaml
    /// </summary>
    public partial class BackgroundActionControl : UserControl, IActionControl
    {
        public string DisplayName { get; private set; }
        public string Description { get; private set; }
        public UserControl UserControl { get { return this; } }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public BackgroundActionControl()
        {
            InitializeComponent();

            DisplayName = TranslationUtil.GetTranslation("BackgroundSettings", "DisplayName", "Add background (only for PDF)");
            Description = TranslationUtil.GetTranslation("BackgroundSettings", "Description", "Add a background to your PDF documents.\r\nThe background file must be a PDF file and may contain multiple pages.");

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ViewModel.CurrentProfile.BackgroundPage.Enabled;
            }
            set
            {
                ViewModel.CurrentProfile.BackgroundPage.Enabled = value;
            }
        }

        private void SelectBackgroundFileButton_OnClick(object sender, RoutedEventArgs e)
        {
            var title = TranslationUtil.GetTranslation("BackgroundSettings", "SelectBackgroundFile", "Select background file");
            var filter = TranslationUtil.GetTranslation("BackgroundSettings", "PDFFiles", "PDF files")
                                    + @" (*.pdf)|*.pdf|"
                                    + TranslationUtil.GetTranslation("BackgroundSettings", "AllFiles", "All files")
                                    + @" (*.*)|*.*";

            FileDialogHelper.ShowSelectFileDialog(BackgroundFileTextBox, title, filter);
        }
    }
}
