﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Win32;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class CoverActionControl : UserControl, IActionControl
    {
        public CoverActionControl()
        {
            InitializeComponent();

            DisplayName = TranslationUtil.GetTranslation("CoverSettings", "DisplayName", "Add cover");
            Description = TranslationUtil.GetTranslation("CoverSettings", "Description", "Add a cover to your documents.\r\nThe cover file must be a PDF file and may contain multiple pages.");

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        public string DisplayName { get; private set; }
        public string Description { get; private set; }
        public UserControl UserControl { get { return this; } }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ViewModel.CurrentProfile.CoverPage.Enabled;
            }
            set
            {
                ViewModel.CurrentProfile.CoverPage.Enabled = value;
            }
        }

        private void SelectCoverFileButton_OnClick(object sender, RoutedEventArgs e)
        {
            var title = TranslationUtil.GetTranslation("CoverSettings", "SelectCoverFile", "Select cover file");
            var filter = TranslationUtil.GetTranslation("CoverSettings", "PDFFiles", "PDF files")
                                    + @" (*.pdf)|*.pdf|"
                                    + TranslationUtil.GetTranslation("CoverSettings", "AllFiles", "All files")
                                    + @" (*.*)|*.*";
            
            FileDialogHelper.ShowSelectFileDialog(CoverFileTextBox, title, filter);
        }
    }
}