﻿using System;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using NLog;
using pdfforge.PDFCreator.Core.Settings;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.ViewModels;
using pdfforge.PDFCreator.Mail;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class EmailClientActionControl : UserControl, IActionControl
    {
        private static Logger _logger = LogManager.GetCurrentClassLogger();
        
        public EmailClientActionControl()
        {
            InitializeComponent();

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        public string DisplayName { get { return TranslationUtil.GetTranslation("EmailClientActionSettings", "DisplayName", "Open e-mail client"); } }

        public string Description
        {
            get
            {
                return TranslationUtil.GetTranslation("EmailClientActionSettings", "Description",
                    "Opens a new e-mail in the default client. There you can add receipients, text and other information and then send the mail to your contacts.");
            }
        }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ((ProfileSettingsViewModel)DataContext).CurrentProfile.EmailClient.Enabled;
            }
            set { ((ProfileSettingsViewModel)DataContext).CurrentProfile.EmailClient.Enabled = value; }
        }

        public UserControl UserControl
        {
            get { return this; }
        }

        private EmailClient EmailClientSettings
        {
            get
            {
                if (DataContext == null)
                    return null;
                return ((ProfileSettingsViewModel) DataContext).CurrentProfile.EmailClient;
            }
        }

        private void EmailClientTestButton_OnClick(object sender, RoutedEventArgs e)
        {
            var emailClientFactory = new EmailClientFactory();
            var emailClient = emailClientFactory.CreateEmailClient();

            if (emailClient == null)
            {
                string caption = TranslationUtil.GetTranslation("EmailClientActionSettings", "CheckMailClient", "Check e-mail client");
                string message = TranslationUtil.GetTranslation("EmailClientActionSettings", "NoMapiClientFound",
                    "Could not find MAPI client (e.g. Thunderbird or Outlook).");
                MessageWindow.ShowTopMost(message, caption, MessageWindowButtons.OK, MessageWindowIcon.Warning);
                return;
            }

            var eMail = new Email();
            eMail.To.Add(EmailClientSettings.Recipients);
            eMail.Subject = EmailClientSettings.Subject;
            eMail.Body = EmailClientSettings.Content + EmailClientSettings.Signature;

            try
            {
                string tempFolder = Path.GetTempPath();
                string tmpTestFolder = Path.Combine(tempFolder, "PDFCreator-Test\\SendSmtpTestmail");
                Directory.CreateDirectory(tmpTestFolder);
                string tmpFile = Path.Combine(tmpTestFolder, "PDFCreator Mail Client Test.pdf");
                File.WriteAllText(tmpFile, "");
                eMail.Attachments.Add(new Attachment(tmpFile));

                emailClient.ShowEmailClient(eMail);
            }
            catch (Exception ex)
            {
                _logger.WarnException("Exception while creating mail", ex);
            }
        }

        private void EditEmailTextButton_OnClick(object sender, RoutedEventArgs e)
        {
            var setEmailTextForm = new EditEmailTextWindow();
            setEmailTextForm.Subject = EmailClientSettings.Subject;
            setEmailTextForm.Body = EmailClientSettings.Content;
            setEmailTextForm.Signature = EmailClientSettings.Signature;

            if (setEmailTextForm.ShowDialog() == true)
            {
                EmailClientSettings.Subject = setEmailTextForm.Subject;
                EmailClientSettings.Content = setEmailTextForm.Body;
                EmailClientSettings.Signature = setEmailTextForm.Signature;
            }
        }
    }
}
