﻿using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using pdfforge.PDFCreator.Core.Actions;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.Utilities.Tokens;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class FtpActionControl : UserControl, IActionControl
    {
        private readonly TokenReplacer _tokenReplacer;

        public List<string> Tokens { get; private set; }
        
        public FtpActionControl() : this(new TokenReplacer())
        {
        }

        public FtpActionControl(TokenReplacer tokenReplacer)
        {
            _tokenReplacer = tokenReplacer;
            Tokens = new List<string>(_tokenReplacer.GetTokenNames(true));

            InitializeComponent();

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        public string DisplayName { get { return TranslationUtil.GetTranslation("FtpActionSettings", "DisplayName", "Upload with FTP"); } }
        public string Description { get { return TranslationUtil.GetTranslation("FtpActionSettings", "Description", "The FTP action allows to upload the created documents to a server via FTP."); } }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ((ProfileSettingsViewModel)DataContext).CurrentProfile.Ftp.Enabled;
            }
            set { ((ProfileSettingsViewModel)DataContext).CurrentProfile.Ftp.Enabled = value; }
        }

        public UserControl UserControl
        {
            get { return this; }
        }

        private string Password
        {
            get
            {
                if (DataContext == null)
                    return null;
                return ((ProfileSettingsViewModel)DataContext).CurrentProfile.Ftp.Password;
            }
            set { ((ProfileSettingsViewModel)DataContext).CurrentProfile.Ftp.Password = value; }
        }

        private void FtpTextBox_OnTextChanged(object sender, TextChangedEventArgs e)
        {
            DirectoryPreviewTextBox.Text = FtpAction.MakeValidPath(_tokenReplacer.ReplaceTokens(DirectoryTextBox.Text));
        }

        private void SetPasswordButton_OnClick(object sender, RoutedEventArgs e)
        {
            var pwWindow = new FtpPasswordWindow(FtpPasswordMiddleButton.Remove);
            pwWindow.FtpPassword = Password;

            pwWindow.ShowDialogTopMost();
            if (pwWindow.Response == FtpPasswordResponse.OK)
            {
                Password = pwWindow.FtpPassword;
            }
            else if (pwWindow.Response == FtpPasswordResponse.Remove)
            {
                Password = "";
            }
        }

        private void TokenComboBox_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            TextBoxHelper.InsertText(DirectoryTextBox, AddTokenComboBox.Items[AddTokenComboBox.SelectedIndex] as string);
        }
    }
}
