﻿using System.Diagnostics;
using System.Windows;
using System.Windows.Controls;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class OpenViewerActionControl : IActionControl
    {
        public string DisplayName { get; private set; }
        public string Description { get; private set; }
        public UserControl UserControl { get { return this; } }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        
        public OpenViewerActionControl()
        {
            InitializeComponent();
            DisplayName = TranslationUtil.GetTranslation("OpenViewerSettings", "DisplayName", "Open Document");
            Description = TranslationUtil.GetTranslation("OpenViewerSettings", "Description", "Open document after saving.");

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ViewModel.CurrentProfile.OpenViewer;
            }
            set
            {
                ViewModel.CurrentProfile.OpenViewer = value;
            }
        }

        private void OpenWithArchitectCheckBox_OnClick(object sender, RoutedEventArgs e)
        {
            if (!ViewModel.CurrentProfile.OpenWithPdfArchitect) 
                return;

            if (PdfArchitectHelper.IsPdfArchitectInstalled)
                return;

            const string caption = "PDF Architect";
            var message = TranslationUtil.GetTranslation("OpenViewerSettings", "ArchitectNotInstalled",
                "PDF Architect is not installed.\r\nDo You want to download it from pdfforge.org?");
            var result = MessageWindow.ShowTopMost(message, caption, MessageWindowButtons.YesNo, MessageWindowIcon.PDFForge);
            if (result == MessageWindowResponse.Yes)
            {
                Process.Start(Urls.ArchitectDownloadUrl);
            }
            OpenWithArchitectCheckBox.IsChecked = false;
        }

        private void GetPdfArchitectButton_OnClick(object sender, RoutedEventArgs e)
        {
            Process.Start(Urls.ArchitectWebsiteUrl);
        }
    }
}