﻿using System.Collections.Generic;
using System.Drawing.Printing;
using System.Linq;
using System.Windows.Controls;
using pdfforge.PDFCreator.Core.Settings.Enums;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class PrintActionControl : UserControl, IActionControl
    {
        public PrintActionControl()
        {
            InitializeComponent();

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        public static IEnumerable<EnumValue<SelectPrinter>> SelectPrinterValues
        {
            get { return TranslationUtil.GetEnumTranslation<SelectPrinter>(); }
        }

        public static IEnumerable<EnumValue<DuplexPrint>> DuplexPrintValues
        {
            get { return TranslationUtil.GetEnumTranslation<DuplexPrint>(); }
        } 

        public string DisplayName
        {
            get { return TranslationUtil.GetTranslation("PrintActionSettings", "DisplayName", "Print document"); }
        }

        public string Description
        {
            get { return TranslationUtil.GetTranslation("PrintActionSettings", "Description", "The print document action allows to print the document to a physical printer in addition to the conversion to PDF or any other format."); }
        }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ((ProfileSettingsViewModel) DataContext).CurrentProfile.Printing.Enabled;
            }
            set { ((ProfileSettingsViewModel)DataContext).CurrentProfile.Printing.Enabled = value; }
        }

        public IEnumerable<string> InstalledPrinters
        {
            get
            {
                var printers = PrinterSettings.InstalledPrinters.Cast<string>().ToList();
                printers.Sort();
                return printers;
            }
        }

        public UserControl UserControl
        {
            get { return this; }
        }
    }
}
