﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Windows;
using System.Windows.Controls;
using Microsoft.Win32;
using pdfforge.PDFCreator.Core.Actions;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.Utilities.Tokens;
using pdfforge.PDFCreator.ViewModels;

namespace pdfforge.PDFCreator.Views.ActionControls
{
    public partial class ScriptActionControl : UserControl, IActionControl
    {
        private readonly TokenReplacer _tokenReplacer;
        public List<string> Tokens { get; private set; }

        public string DisplayName { get { return TranslationUtil.GetTranslation("ScriptActionSettings", "DisplayName", "Run script"); } }
        public string Description { get { return TranslationUtil.GetTranslation("ScriptActionSettings", "Description", "The script action runs a custom script or application after the conversion. This allows you to further process the output."); } }

        public ScriptActionControl()
        {
            _tokenReplacer = TokenHelper.TokenReplacerWithPlaceHolders;
            Tokens = new List<string>(_tokenReplacer.GetTokenNames(true));

            InitializeComponent();

            TranslationUtil.TranslatorInstance.Translate(this);
        }

        private ProfileSettingsViewModel ViewModel
        {
            get { return (ProfileSettingsViewModel)DataContext; }
        }

        public bool IsActionEnabled
        {
            get
            {
                if (DataContext == null || ViewModel.CurrentProfile == null)
                    return false;
                return ((ProfileSettingsViewModel)DataContext).CurrentProfile.Scripting.Enabled;
            }
            set { ((ProfileSettingsViewModel)DataContext).CurrentProfile.Scripting.Enabled = value; }
        }

        public UserControl UserControl
        {
            get { return this; }
        }

        private void BrowseScriptButton_OnClick(object sender, RoutedEventArgs e)
        {
            var title = TranslationUtil.GetTranslation("ScriptActionSettings", "SelectScriptTitle", "Select script file");
            var filter = TranslationUtil.GetTranslation("ScriptActionSettings", "ExecutableFiles", "Executable files")
                + @" (*.exe, *.bat, *.cmd)|*.exe;*.bat;*.cmd|"
                + TranslationUtil.GetTranslation("ScriptActionSettings", "AllFiles", "All files")
                + @"(*.*)|*.*";
            
            FileDialogHelper.ShowSelectFileDialog(ScriptFileTextBox, title, filter);
        }

        private void ScriptFileTextBox_OnTextChanged(object sender, TextChangedEventArgs e)
        {
            ScriptCallPreviewTextBox.Text = ComposeSampleCommand(ScriptFileTextBox.Text, AdditionalParametersTextBox.Text);
        }

        private string ComposeSampleCommand(string scriptPath, string additionalParams)
        {
            if ((string.IsNullOrEmpty(scriptPath)) || (scriptPath.Trim().Length == 0))
                return "";

            //TokenReplacer tokenReplacer = TokenHelper.TokenReplacerWithPlaceHolders;

            string scriptCall = Path.GetFileName(ScriptAction.ComposeScriptPath(scriptPath, _tokenReplacer));

            if (!string.IsNullOrEmpty(additionalParams))
            {
                scriptCall += " " + ScriptAction.ComposeScriptParameters(additionalParams, new[] { @"C:\File1.pdf", @"C:\File2.pdf" }, _tokenReplacer);
            }
            else
            {
                scriptCall += @" C:\File1.pdf C:\File2.pdf";
            }

            return scriptCall;
        }

        private void AddParameterTokenComboBox_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            TextBoxHelper.InsertText(AdditionalParametersTextBox, AddParameterTokenComboBox.Items[AddParameterTokenComboBox.SelectedIndex] as string);
        }

        private void AddScriptTokenComboBox_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            TextBoxHelper.InsertText(ScriptFileTextBox, AddScriptTokenComboBox.Items[AddScriptTokenComboBox.SelectedIndex] as string);
        }
    }
}
