﻿using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using pdfforge.PDFCreator.Converter;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.Utilities.Tokens;

namespace pdfforge.PDFCreator.Views
{
    public partial class EditEmailTextWindow : Window
    {
        public string Subject
        {
            get { return SubjectText.Text; }
            set { SubjectText.Text = value; }
        }

        public string Body
        {
            get { return BodyText.Text; }
            set { BodyText.Text = value; }
        }

        public string Signature
        {
            get { return BodyTokenReplacerConverter.Footer; }
            set
            {
                BodyTokenReplacerConverter.Footer = value;
                AttachSignature.IsChecked = !string.IsNullOrWhiteSpace(value);
            }
        }

        private TokenReplacerConverter BodyTokenReplacerConverter
        {
            get { return FindResource("TokenReplacerConverterWithFooter") as TokenReplacerConverter; }
        }

        private TokenReplacerConverter HeaderTokenReplacerConverter
        {
            get { return FindResource("TokenReplacerConverter") as TokenReplacerConverter; }
        }

        public EditEmailTextWindow()
        {
            InitializeComponent();

            TranslationUtil.TranslatorInstance.Translate(this);
            
            BodyTokenReplacerConverter.TokenReplacer = TokenHelper.TokenReplacerWithPlaceHolders;
            HeaderTokenReplacerConverter.TokenReplacer = BodyTokenReplacerConverter.TokenReplacer;

            var tokens = TokenHelper.GetTokenListForEmail();

            SubjectTokenComboBox.ItemsSource = tokens;
            BodyTokenComboBox.ItemsSource = tokens;
        }

        private void OkButton_OnClick(object sender, RoutedEventArgs e)
        {
            DialogResult = true;
        }

        private void AttachSignature_OnChecked(object sender, RoutedEventArgs e)
        {
            CheckBox chk = sender as CheckBox;
            if (chk.IsChecked == true)
            {
                Signature = "\r\n\r\n______________________________\r\n\r\n"
                                 +
                                 TranslationUtil.GetTranslation("EditEmailTextWindow", "PdfForgeSignature",
                                     "E-mail automatically created by the free PDFCreator")
                                 + "\r\nwww.pdfforge.org";
            }
            else
            {
                Signature = "";
            }

            BodyTokenReplacerConverter.Footer = Signature;

            BindingExpression be = FinalBodyText.GetBindingExpression(TextBox.TextProperty);
            be.UpdateTarget();
        }

        private void SubjectTokenComboBox_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            InsertToken(SubjectText, (ComboBox)sender);
        }

        private void BodyTokenComboBox_OnSelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            InsertToken(BodyText, (ComboBox)sender);
        }

        private void InsertToken(TextBox txt, ComboBox cmb)
        {
            string text = cmb.SelectedItem.ToString();
            int newSelectionStart = txt.SelectionStart + text.Length;
            txt.Text = txt.Text.Insert(txt.SelectionStart, text);
            txt.SelectionStart = newSelectionStart;
        }
    }
}
