﻿using System;
using System.Windows;
using System.Windows.Input;
using pdfforge.PDFCreator.Core.Settings;
using pdfforge.PDFCreator.Helper;
using pdfforge.PDFCreator.Properties;

namespace pdfforge.PDFCreator.Views
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        private void AppSettingsButton_OnClick(object sender, RoutedEventArgs e)
        {
            PdfCreatorSettings settings = SettingsHelper.Settings;
            string currentLanguage = settings.ApplicationSettings.Language;

            ApplicationSettings tmpSettings = settings.ApplicationSettings.Copy();
            var tmpProperties = settings.ApplicationProperties.Copy();
            var window = new ApplicationSettingsWindow(tmpSettings, tmpProperties, settings.ConversionProfiles);

            if (window.ShowDialog() == true)
            {
                settings.ApplicationSettings = tmpSettings;
                settings.ApplicationProperties = tmpProperties;
                if (!string.Equals(currentLanguage, settings.ApplicationSettings.Language, StringComparison.InvariantCultureIgnoreCase))
                {
                    TranslationUtil.InitTranslator(settings);
                    TranslationUtil.TranslatorInstance.Translate(this);
                }
                //Translation of profiles are stored in their name property and could have been changed in the appsettingswindow
                //To include the current language ist must be translated here 
                TranslationUtil.TranslateProfileList(SettingsHelper.Settings.ConversionProfiles);
                
                SettingsHelper.SaveSettings();
            }

            LoggingUtil.ApplyLogging(settings.ApplicationSettings.LoggingLevel);
        }

        private void ProfileSettingsButton_OnClick(object sender, RoutedEventArgs e)
        {
            var window = new ProfileSettingsWindow(SettingsHelper.Settings);
            window.ShowDialog();
        }

        private void MainWindow_OnLoaded(object sender, RoutedEventArgs e)
        {
            TranslationUtil.TranslatorInstance.Translate(this);
            
            var v = System.Reflection.Assembly.GetExecutingAssembly().GetName().Version;
            ApplicationNameText.Text = string.Format("PDFCreator {0}.{1}", v.Major, v.Minor);

            // Apply company name for customized setups
            ApplyCustomization();

            //Show welcome window on first run of application
            if (Settings.Default.FirstRun)
            {
                Settings.Default.FirstRun = false;
                Settings.Default.Save();

                WelcomeWindow.ShowDialogTopMost();
            }
        }

        private void ApplyCustomization()
        {
            if (Properties.Licensing.ApplyLicensing.Equals("true", StringComparison.CurrentCultureIgnoreCase))
            {
                LicensedForText.Visibility = Visibility.Visible;
                LicensedForText.Text = Properties.Licensing.MainForm;
            }
            else
            {
                LicensedForText.Visibility = Visibility.Hidden;
            }
        }

        private void HelpButton_Click(object sender, RoutedEventArgs e)
        {
            var w = new AboutWindow();
            w.ShowDialog();
        }

        private void MainWindow_OnKeyDown(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.F1)
            {
                HelpFileUtil.ShowHelp(HelpTopic.General);
            }
        }

        private void MainWindow_OnDragEnter(object sender, DragEventArgs e)
        {
            if (((string[])e.Data.GetData(DataFormats.FileDrop)).Length == 0)
                e.Effects = DragDropEffects.None;
            else
                e.Effects = DragDropEffects.Copy;
        }

        private void MainWindow_OnDrop(object sender, DragEventArgs e)
        {
            var printFile = new PrintFileHelper();
            if (printFile.AddFiles((string[])e.Data.GetData(DataFormats.FileDrop, false)))
                printFile.PrintAll();
        }
    }
}
